==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.md <==
# AwsIdentityAccessManagementEncryptedData


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')
```



| Illustration | AwsIdentityAccessManagementEncryptedData | AwsIdentityAccessManagementEncryptedDataCard | AwsIdentityAccessManagementEncryptedDataGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.png) | ![illustration for AwsIdentityAccessManagementEncryptedData](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.Local.png) | ![illustration for AwsIdentityAccessManagementEncryptedDataCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedDataCard.Local.png) | ![illustration for AwsIdentityAccessManagementEncryptedDataGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedDataGroup.Local.png) |




## AwsIdentityAccessManagementEncryptedData

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedData
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedData('AwsIdentityAccessManagementEncryptedData', 'Aws Identity Access Management Encrypted Data', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedData
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedData('AwsIdentityAccessManagementEncryptedData', 'Aws Identity Access Management Encrypted Data', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementEncryptedDataCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataCard('AwsIdentityAccessManagementEncryptedDataCard', 'Aws Identity Access Management Encrypted Data Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataCard('AwsIdentityAccessManagementEncryptedDataCard', 'Aws Identity Access Management Encrypted Data Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementEncryptedDataGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataGroup('AwsIdentityAccessManagementEncryptedDataGroup', 'Aws Identity Access Management Encrypted Data Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataGroup('AwsIdentityAccessManagementEncryptedDataGroup', 'Aws Identity Access Management Encrypted Data Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.md <==
# AwsIdentityAccessManagementEncryptedData


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')
```



| Illustration | AwsIdentityAccessManagementEncryptedData | AwsIdentityAccessManagementEncryptedDataCard | AwsIdentityAccessManagementEncryptedDataGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.png) | ![illustration for AwsIdentityAccessManagementEncryptedData](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData.Local.png) | ![illustration for AwsIdentityAccessManagementEncryptedDataCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedDataCard.Local.png) | ![illustration for AwsIdentityAccessManagementEncryptedDataGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedDataGroup.Local.png) |




## AwsIdentityAccessManagementEncryptedData

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedData
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedData('AwsIdentityAccessManagementEncryptedData', 'Aws Identity Access Management Encrypted Data', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedData
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedData('AwsIdentityAccessManagementEncryptedData', 'Aws Identity Access Management Encrypted Data', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementEncryptedDataCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataCard('AwsIdentityAccessManagementEncryptedDataCard', 'Aws Identity Access Management Encrypted Data Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataCard('AwsIdentityAccessManagementEncryptedDataCard', 'Aws Identity Access Management Encrypted Data Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementEncryptedDataGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataGroup('AwsIdentityAccessManagementEncryptedDataGroup', 'Aws Identity Access Management Encrypted Data Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementEncryptedDataGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementEncryptedData')

' renders the element
AwsIdentityAccessManagementEncryptedDataGroup('AwsIdentityAccessManagementEncryptedDataGroup', 'Aws Identity Access Management Encrypted Data Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
